From: Sean V Kelley <sean.v.kel...@intel.com>

The term "dev" is being applied to root ports, switch
upstream ports, switch downstream ports, and the upstream
ports on endpoints. While endpoint upstream ports don't have
subordinate buses, a generic term such as "bridge" may be used
for something with a subordinate bus. The current conditional
logic in pcie_do_recovery() would also benefit from some
simplification with use of pci_upstream_bridge() in place of
dev->bus->self. Reverse the pcie_do_recovery() conditional logic
and replace use of "dev" with "bridge" for greater clarity.

Suggested-by: Bjorn Helgaas <bhelg...@google.com>
Signed-off-by: Sean V Kelley <sean.v.kel...@intel.com>
---
 drivers/pci/pcie/err.c | 20 +++++++++++++-------
 1 file changed, 13 insertions(+), 7 deletions(-)

diff --git a/drivers/pci/pcie/err.c b/drivers/pci/pcie/err.c
index 950612342f1c..c6922c099c76 100644
--- a/drivers/pci/pcie/err.c
+++ b/drivers/pci/pcie/err.c
@@ -152,16 +152,22 @@ pci_ers_result_t pcie_do_recovery(struct pci_dev *dev,
 {
        pci_ers_result_t status = PCI_ERS_RESULT_CAN_RECOVER;
        struct pci_bus *bus;
+       struct pci_dev *bridge;
+       int type;
 
        /*
         * Error recovery runs on all subordinates of the first downstream port.
         * If the downstream port detected the error, it is cleared at the end.
         */
-       if (!(pci_pcie_type(dev) == PCI_EXP_TYPE_ROOT_PORT ||
-             pci_pcie_type(dev) == PCI_EXP_TYPE_DOWNSTREAM))
-               dev = dev->bus->self;
-       bus = dev->subordinate;
-
+       type = pci_pcie_type(dev);
+       if (type == PCI_EXP_TYPE_ROOT_PORT ||
+           type == PCI_EXP_TYPE_DOWNSTREAM)
+               bridge = dev;
+       else
+               bridge = pci_upstream_bridge(dev);
+
+       bus = bridge->subordinate;
        pci_dbg(dev, "broadcast error_detected message\n");
        if (state == pci_channel_io_frozen) {
                pci_walk_bus(bus, report_frozen_detected, &status);
@@ -152,16 +152,22 @@ pci_ers_result_t pcie_do_recovery(struct pci_dev *dev,
 
        /*
-        * Error recovery runs on all subordinates of the first downstream port.
-        * If the downstream port detected the error, it is cleared at the end.
+        * Error recovery runs on all subordinates of the first downstream
+        * bridge. If the downstream bridge detected the error, it is
+        * cleared at the end.
         */
-- 
2.28.0

Reply via email to